==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/AttachedVolumeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class AttachedVolumeBuilder extends AttachedVolumeFluentImpl<AttachedVolumeBuilder> implements VisitableBuilder<AttachedVolume,AttachedVolumeBuilder>{

    AttachedVolumeFluent<?> fluent;
    Boolean validationEnabled;

    public AttachedVolumeBuilder(){
            this(true);
    }
    public AttachedVolumeBuilder(Boolean validationEnabled){
            this(new AttachedVolume(), validationEnabled);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent){
            this(fluent, true);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new AttachedVolume(), validationEnabled);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,AttachedVolume instance){
            this(fluent, instance, true);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,AttachedVolume instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDevicePath(instance.getDevicePath()); 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public AttachedVolumeBuilder(AttachedVolume instance){
            this(instance,true);
    }
    public AttachedVolumeBuilder(AttachedVolume instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public AttachedVolume build(){
            AttachedVolume buildable = new AttachedVolume(fluent.getDevicePath(),fluent.getName());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AttachedVolumeBuilder that = (AttachedVolumeBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/AttachedVolumeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class AttachedVolumeBuilder extends AttachedVolumeFluentImpl<AttachedVolumeBuilder> implements VisitableBuilder<AttachedVolume,AttachedVolumeBuilder>{

    AttachedVolumeFluent<?> fluent;
    Boolean validationEnabled;

    public AttachedVolumeBuilder(){
            this(true);
    }
    public AttachedVolumeBuilder(Boolean validationEnabled){
            this(new AttachedVolume(), validationEnabled);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent){
            this(fluent, true);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new AttachedVolume(), validationEnabled);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,AttachedVolume instance){
            this(fluent, instance, true);
    }
    public AttachedVolumeBuilder(AttachedVolumeFluent<?> fluent,AttachedVolume instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDevicePath(instance.getDevicePath()); 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public AttachedVolumeBuilder(AttachedVolume instance){
            this(instance,true);
    }
    public AttachedVolumeBuilder(AttachedVolume instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDevicePath(instance.getDevicePath()); 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public AttachedVolume build(){
            AttachedVolume buildable = new AttachedVolume(fluent.getDevicePath(),fluent.getName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AttachedVolumeBuilder that = (AttachedVolumeBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
